@@ -73,84 +73,7 @@ class WebApplication(Application):
                     return hdr
                 raise HTTPError(404)
         super(WebApplication, self).__call__(request)
-        #print """Called by HTTPServer to execute the request."""
-        #print "##################################################"
-        ##interact(local=locals())
-        #transforms = [t(request) for t in self.transforms]
-        #handler = None
-        #args = []
-        #kwargs = {}
-        ## removeslash
-        #
-        #if request.path.endswith("/"):
-        #    if request.method in ("GET", "HEAD"):
-        #        uri = request.path.rstrip("/")
-        #        if uri:  # don't try to redirect '/' to ''
-        #            if request.query:
-        #                uri += "?" + request.query
-        #            hdr = RedirectHandler(self, request, url=uri)
-        #            hdr._execute(transforms, *args, **kwargs)
-        #            return hdr
-        #    else:
-        #        raise HTTPError(404)
-        #
-        ## addslash
-        ##li = [_compile for _compile in self._static_urls if re.compile(_compile).match(request.path)]
-        ##if len(li) == 0 and not request.path.endswith("/"):
-        ##    if request.method in ("GET", "HEAD"):
-        ##        uri = request.path + "/"
-        ##        if request.query:
-        ##            uri += "?" + request.query
-        ##        hdr = RedirectHandler(self, request, url=uri)
-        ##        hdr._execute(transforms, *args, **kwargs)
-        ##        return hdr
-        ##    raise HTTPError(404)
-        #handlers = self._get_host_handlers(request)
-        #if not handlers:
-        #    handler = RedirectHandler(
-        #        self, request, url="http://" + self.default_host + "/")
-        #else:
-        #    for spec in handlers:
-        #        match = spec.regex.match(request.path)
-        #        static_flag = spec.kwargs.has_key('path') \
-        #                and hasattr(spec.handler_class, 'static_handler') \
-        #                and spec.handler_class.static_handler == True
-        #        if match:
-        #            handler = spec.handler_class(self, request, **spec.kwargs)
-        #            if spec.regex.groups:
-        #                # None-safe wrapper around url_unescape to handle
-        #                # unmatched optional groups correctly
-        #                def unquote(s):
-        #                    if s is None:
-        #                        return s
-        #                    from tornado import escape
-        #                    return escape.url_unescape(s, encoding=None)
-        #                # Pass matched groups to the handler.  Since
-        #                # match.groups() includes both named and unnamed groups,
-        #                # we want to use either groups or groupdict but not both.
-        #                # Note that args are passed as bytes so the handler can
-        #                # decide what encoding to use.
 
-        #                if spec.regex.groupindex:
-        #                    kwargs = dict(
-        #                        (str(k), unquote(v))
-        #                        for (k, v) in match.groupdict().iteritems())
-        #                else:
-        #                    args = [unquote(s) for s in match.groups()]
-        #            break
-        #    if not handler:
-        #        handler = ErrorHandler(self, request, status_code=404)
-
-        ## In debug mode, re-compile templates and reload static files on every
-        ## request so you don't need to restart to see changes
-        #if self.settings.get("debug"):
-        #    with RequestHandler._template_loader_lock:
-        #        for loader in RequestHandler._template_loaders.values():
-        #            loader.reset()
-        #    _StaticFileHandler.reset()
-
-        #handler._execute(transforms, *args, **kwargs)
-        #return handler
 
 class WSGIApplication(_WSGIApplication):
     def __call__(self, environ):
@@ -219,24 +142,32 @@ def get_current_traceback():
     return traceback
 
  
-def make_application(app, debug=False, wsgi=False):
+def make_application(app, debug=False, wsgi=False, settings_path="", url_root="/"):
     app_path = os.path.abspath(os.path.dirname(app.__file__))
-    if hasattr(app, 'settings'):
-        conf = app.settings
-    else:
-        conf = Yaml_Config(app_path, os.path.join(app_path, 'settings.yaml'))
+    conf = None
+    if settings_path != "":
+        #conf = app.settings
+        conf = Yaml_Config(app_path, settings_path, url_root=url_root)
+    #else:
+    #    conf = Yaml_Config(app_path, os.path.join(app_path, 'settings.yaml'), url_root=url_root)
     views_path = os.path.join(app_path, 'views')
+    module_list = []
     for module, name in get_modules([app.__name__, 'views'], views_path):
         if type(module) == tuple:
             module = module[0]
-        __import__(module, {}, {}, name)
+        m = __import__(module, {}, {}, name)
+        module_list.append(m)
     from torweb.urls import url, except_url
     def _set_debug(kw):
         kw["debug"] = debug
         return kw
     url_handlers = url.handlers
-    url_handlers = [URLSpec(spec._path, spec.handler_class, _set_debug(spec.kwargs), spec.name) for spec in url_handlers]
-    _static_urls = [spec._path for spec in url.handlers if spec.kwargs.has_key("path") and hasattr(spec.handler_class, 'static_handler') and spec.handler_class.static_handler==True]
+    url_handlers = [URLSpec(spec.regex.pattern, spec.handler_class, _set_debug(spec.kwargs), spec.name) for spec in url_handlers]
+    if hasattr(app, "url"):
+        app_url_handlers = app.url.handlers
+        app_url_handlers = [URLSpec(spec.regex.pattern, spec.handler_class, _set_debug(spec.kwargs), spec.name) for spec in app_url_handlers]
+        url_handlers.extend(app_url_handlers)
+    _static_urls = [spec.regex.pattern for spec in url.handlers if spec.kwargs.has_key("path") and hasattr(spec.handler_class, 'static_handler') and spec.handler_class.static_handler==True]
     #url_handlers = [(u, c, _set_debug(kw)) for u, c, kw in url_handlers]
     #_static_urls = [url for url, cls, kw in url.handlers if kw.has_key("path") and hasattr(cls, 'static_handler') and cls.static_handler==True]
     url_handlers.extend(except_url.handlers)
@@ -250,7 +181,8 @@ def make_application(app, debug=False, wsgi=False):
     application.url_handlers = url_handlers
     application._static_urls = _static_urls
     # 初始化session store
-    application.session_store = conf.session_store
+    if conf:
+        application.session_store = conf.session_store
     return application
 
 class InitializeApplication(object):
