@@ -28,7 +28,7 @@ def urls(app):
     def action():
         """show all urls"""
         for spec in app.url_handlers:
-            print "%s\t\t\t%s(%s)"%(spec._path, spec.handler_class, spec.kwargs)
+            print "%s\t\t\t%s(%s)"%(spec.regex.pattern, spec.handler_class, spec.kwargs)
 
     return action
 
