@@ -7,7 +7,7 @@ import yaml
 from code import interact
 
 class Yaml_Config(object):
-    def __init__(self, base_path, yaml_path):
+    def __init__(self, base_path, yaml_path, url_root="/"):
         self.yaml_path = yaml_path
         f = open(self.yaml_path)
         self.settings = yaml.load(f)
@@ -17,6 +17,7 @@ class Yaml_Config(object):
         self.base_path = base_path
         self.init_store()
         self.init_propertys()
+        self.set_url_root(url_root)
     def init_propertys(self):
         #self.app.base_path = self.base_path
         self.app.static_path = self.static_path
@@ -50,6 +51,11 @@ class Yaml_Config(object):
             domain = self.settings.get('static_domain', '/static')
             setattr(self, '_static_domain', domain)
         return getattr(self, '_static_domain')
+    def set_url_root(self, url_root):
+        #url_root = self.settings.get('url_root', '/')
+        self.app.url_root = self.url_root = url_root
+        from torweb.urls import Url
+        self.app.url = Url(url_root)
     @property
     def cache(self):
         if not hasattr(self, '_cache'):
